@@ -38,7 +38,7 @@ except ImportError:
     from sphinx import apidoc
 
 output_dir = os.path.join(__location__, "api")
-module_dir = os.path.join(__location__, "../src/bbox")
+module_dir = os.path.join(__location__, "../src/bbox_utils")
 try:
     shutil.rmtree(output_dir)
 except FileNotFoundError:
